Package 'DataSchema'

Title: Tools for schemas describing and validating data sets
Description: JSON Schemas (see https://json-schema.org/learn/getting-started-step-by-step) can be useful for many things like generating SQL databases, structured RDS data sets, validation of data, structuring AI output, creating autmatic documentation etc. I have used and developed several ad-hoc schema specifications / tools in different packages, like "dbmisc" (yaml), "repboxdb" (yaml), rgemini (JSON schema from R). This package shall provide helper functions to build, convert and use schemas. While importa and export to json-schema is possible, it is skewed to my taste and my previous application.
Authors: Sebastian Kranz
Maintainer: Sebastian Kranz <[email protected]>
License: GPL >= 2.0
Version: 0.1.0
Built: 2026-05-26 07:40:06 UTC
Source: https://github.com/skranz/DataSchema

Help Index